@@ -1,5 +1,4 @@
 """Unicode Properties from Unicode version 9.0.0 (autogen)."""
-from __future__ import unicode_literals
 
 unicode_blocks = {
     "basiclatin": "\x00-\x7f",
@@ -553,551 +552,551 @@ unicode_blocks = {
 }
 ascii_blocks = {
     "basiclatin": "\x00-\x7f",
-    "^basiclatin": "\x80-\xff",
-    "latin1supplement": "\x80-\xff",
-    "^latin1supplement": "\x00-\x7f",
+    "^basiclatin": "\x80-\U0010ffff",
+    "latin1supplement": "",
+    "^latin1supplement": "\x00-\U0010ffff",
     "latinextendeda": "",
-    "^latinextendeda": "\x00-\xff",
+    "^latinextendeda": "\x00-\U0010ffff",
     "latinextendedb": "",
-    "^latinextendedb": "\x00-\xff",
+    "^latinextendedb": "\x00-\U0010ffff",
     "ipaextensions": "",
-    "^ipaextensions": "\x00-\xff",
+    "^ipaextensions": "\x00-\U0010ffff",
     "spacingmodifierletters": "",
-    "^spacingmodifierletters": "\x00-\xff",
+    "^spacingmodifierletters": "\x00-\U0010ffff",
     "combiningdiacriticalmarks": "",
-    "^combiningdiacriticalmarks": "\x00-\xff",
+    "^combiningdiacriticalmarks": "\x00-\U0010ffff",
     "greekandcoptic": "",
-    "^greekandcoptic": "\x00-\xff",
+    "^greekandcoptic": "\x00-\U0010ffff",
     "cyrillic": "",
-    "^cyrillic": "\x00-\xff",
+    "^cyrillic": "\x00-\U0010ffff",
     "cyrillicsupplement": "",
-    "^cyrillicsupplement": "\x00-\xff",
+    "^cyrillicsupplement": "\x00-\U0010ffff",
     "armenian": "",
-    "^armenian": "\x00-\xff",
+    "^armenian": "\x00-\U0010ffff",
     "hebrew": "",
-    "^hebrew": "\x00-\xff",
+    "^hebrew": "\x00-\U0010ffff",
     "arabic": "",
-    "^arabic": "\x00-\xff",
+    "^arabic": "\x00-\U0010ffff",
     "syriac": "",
-    "^syriac": "\x00-\xff",
+    "^syriac": "\x00-\U0010ffff",
     "arabicsupplement": "",
-    "^arabicsupplement": "\x00-\xff",
+    "^arabicsupplement": "\x00-\U0010ffff",
     "thaana": "",
-    "^thaana": "\x00-\xff",
+    "^thaana": "\x00-\U0010ffff",
     "nko": "",
-    "^nko": "\x00-\xff",
+    "^nko": "\x00-\U0010ffff",
     "samaritan": "",
-    "^samaritan": "\x00-\xff",
+    "^samaritan": "\x00-\U0010ffff",
     "mandaic": "",
-    "^mandaic": "\x00-\xff",
+    "^mandaic": "\x00-\U0010ffff",
     "arabicextendeda": "",
-    "^arabicextendeda": "\x00-\xff",
+    "^arabicextendeda": "\x00-\U0010ffff",
     "devanagari": "",
-    "^devanagari": "\x00-\xff",
+    "^devanagari": "\x00-\U0010ffff",
     "bengali": "",
-    "^bengali": "\x00-\xff",
+    "^bengali": "\x00-\U0010ffff",
     "gurmukhi": "",
-    "^gurmukhi": "\x00-\xff",
+    "^gurmukhi": "\x00-\U0010ffff",
     "gujarati": "",
-    "^gujarati": "\x00-\xff",
+    "^gujarati": "\x00-\U0010ffff",
     "oriya": "",
-    "^oriya": "\x00-\xff",
+    "^oriya": "\x00-\U0010ffff",
     "tamil": "",
-    "^tamil": "\x00-\xff",
+    "^tamil": "\x00-\U0010ffff",
     "telugu": "",
-    "^telugu": "\x00-\xff",
+    "^telugu": "\x00-\U0010ffff",
     "kannada": "",
-    "^kannada": "\x00-\xff",
+    "^kannada": "\x00-\U0010ffff",
     "malayalam": "",
-    "^malayalam": "\x00-\xff",
+    "^malayalam": "\x00-\U0010ffff",
     "sinhala": "",
-    "^sinhala": "\x00-\xff",
+    "^sinhala": "\x00-\U0010ffff",
     "thai": "",
-    "^thai": "\x00-\xff",
+    "^thai": "\x00-\U0010ffff",
     "lao": "",
-    "^lao": "\x00-\xff",
+    "^lao": "\x00-\U0010ffff",
     "tibetan": "",
-    "^tibetan": "\x00-\xff",
+    "^tibetan": "\x00-\U0010ffff",
     "myanmar": "",
-    "^myanmar": "\x00-\xff",
+    "^myanmar": "\x00-\U0010ffff",
     "georgian": "",
-    "^georgian": "\x00-\xff",
+    "^georgian": "\x00-\U0010ffff",
     "hanguljamo": "",
-    "^hanguljamo": "\x00-\xff",
+    "^hanguljamo": "\x00-\U0010ffff",
     "ethiopic": "",
-    "^ethiopic": "\x00-\xff",
+    "^ethiopic": "\x00-\U0010ffff",
     "ethiopicsupplement": "",
-    "^ethiopicsupplement": "\x00-\xff",
+    "^ethiopicsupplement": "\x00-\U0010ffff",
     "cherokee": "",
-    "^cherokee": "\x00-\xff",
+    "^cherokee": "\x00-\U0010ffff",
     "unifiedcanadianaboriginalsyllabics": "",
-    "^unifiedcanadianaboriginalsyllabics": "\x00-\xff",
+    "^unifiedcanadianaboriginalsyllabics": "\x00-\U0010ffff",
     "ogham": "",
-    "^ogham": "\x00-\xff",
+    "^ogham": "\x00-\U0010ffff",
     "runic": "",
-    "^runic": "\x00-\xff",
+    "^runic": "\x00-\U0010ffff",
     "tagalog": "",
-    "^tagalog": "\x00-\xff",
+    "^tagalog": "\x00-\U0010ffff",
     "hanunoo": "",
-    "^hanunoo": "\x00-\xff",
+    "^hanunoo": "\x00-\U0010ffff",
     "buhid": "",
-    "^buhid": "\x00-\xff",
+    "^buhid": "\x00-\U0010ffff",
     "tagbanwa": "",
-    "^tagbanwa": "\x00-\xff",
+    "^tagbanwa": "\x00-\U0010ffff",
     "khmer": "",
-    "^khmer": "\x00-\xff",
+    "^khmer": "\x00-\U0010ffff",
     "mongolian": "",
-    "^mongolian": "\x00-\xff",
+    "^mongolian": "\x00-\U0010ffff",
     "unifiedcanadianaboriginalsyllabicsextended": "",
-    "^unifiedcanadianaboriginalsyllabicsextended": "\x00-\xff",
+    "^unifiedcanadianaboriginalsyllabicsextended": "\x00-\U0010ffff",
     "limbu": "",
-    "^limbu": "\x00-\xff",
+    "^limbu": "\x00-\U0010ffff",
     "taile": "",
-    "^taile": "\x00-\xff",
+    "^taile": "\x00-\U0010ffff",
     "newtailue": "",
-    "^newtailue": "\x00-\xff",
+    "^newtailue": "\x00-\U0010ffff",
     "khmersymbols": "",
-    "^khmersymbols": "\x00-\xff",
+    "^khmersymbols": "\x00-\U0010ffff",
     "buginese": "",
-    "^buginese": "\x00-\xff",
+    "^buginese": "\x00-\U0010ffff",
     "taitham": "",
-    "^taitham": "\x00-\xff",
+    "^taitham": "\x00-\U0010ffff",
     "combiningdiacriticalmarksextended": "",
-    "^combiningdiacriticalmarksextended": "\x00-\xff",
+    "^combiningdiacriticalmarksextended": "\x00-\U0010ffff",
     "balinese": "",
-    "^balinese": "\x00-\xff",
+    "^balinese": "\x00-\U0010ffff",
     "sundanese": "",
-    "^sundanese": "\x00-\xff",
+    "^sundanese": "\x00-\U0010ffff",
     "batak": "",
-    "^batak": "\x00-\xff",
+    "^batak": "\x00-\U0010ffff",
     "lepcha": "",
-    "^lepcha": "\x00-\xff",
+    "^lepcha": "\x00-\U0010ffff",
     "olchiki": "",
-    "^olchiki": "\x00-\xff",
+    "^olchiki": "\x00-\U0010ffff",
     "cyrillicextendedc": "",
-    "^cyrillicextendedc": "\x00-\xff",
+    "^cyrillicextendedc": "\x00-\U0010ffff",
     "sundanesesupplement": "",
-    "^sundanesesupplement": "\x00-\xff",
+    "^sundanesesupplement": "\x00-\U0010ffff",
     "vedicextensions": "",
-    "^vedicextensions": "\x00-\xff",
+    "^vedicextensions": "\x00-\U0010ffff",
     "phoneticextensions": "",
-    "^phoneticextensions": "\x00-\xff",
+    "^phoneticextensions": "\x00-\U0010ffff",
     "phoneticextensionssupplement": "",
-    "^phoneticextensionssupplement": "\x00-\xff",
+    "^phoneticextensionssupplement": "\x00-\U0010ffff",
     "combiningdiacriticalmarkssupplement": "",
-    "^combiningdiacriticalmarkssupplement": "\x00-\xff",
+    "^combiningdiacriticalmarkssupplement": "\x00-\U0010ffff",
     "latinextendedadditional": "",
-    "^latinextendedadditional": "\x00-\xff",
+    "^latinextendedadditional": "\x00-\U0010ffff",
     "greekextended": "",
-    "^greekextended": "\x00-\xff",
+    "^greekextended": "\x00-\U0010ffff",
     "generalpunctuation": "",
-    "^generalpunctuation": "\x00-\xff",
+    "^generalpunctuation": "\x00-\U0010ffff",
     "superscriptsandsubscripts": "",
-    "^superscriptsandsubscripts": "\x00-\xff",
+    "^superscriptsandsubscripts": "\x00-\U0010ffff",
     "currencysymbols": "",
-    "^currencysymbols": "\x00-\xff",
+    "^currencysymbols": "\x00-\U0010ffff",
     "combiningdiacriticalmarksforsymbols": "",
-    "^combiningdiacriticalmarksforsymbols": "\x00-\xff",
+    "^combiningdiacriticalmarksforsymbols": "\x00-\U0010ffff",
     "letterlikesymbols": "",
-    "^letterlikesymbols": "\x00-\xff",
+    "^letterlikesymbols": "\x00-\U0010ffff",
     "numberforms": "",
-    "^numberforms": "\x00-\xff",
+    "^numberforms": "\x00-\U0010ffff",
     "arrows": "",
-    "^arrows": "\x00-\xff",
+    "^arrows": "\x00-\U0010ffff",
     "mathematicaloperators": "",
-    "^mathematicaloperators": "\x00-\xff",
+    "^mathematicaloperators": "\x00-\U0010ffff",
     "miscellaneoustechnical": "",
-    "^miscellaneoustechnical": "\x00-\xff",
+    "^miscellaneoustechnical": "\x00-\U0010ffff",
     "controlpictures": "",
-    "^controlpictures": "\x00-\xff",
+    "^controlpictures": "\x00-\U0010ffff",
     "opticalcharacterrecognition": "",
-    "^opticalcharacterrecognition": "\x00-\xff",
+    "^opticalcharacterrecognition": "\x00-\U0010ffff",
     "enclosedalphanumerics": "",
-    "^enclosedalphanumerics": "\x00-\xff",
+    "^enclosedalphanumerics": "\x00-\U0010ffff",
     "boxdrawing": "",
-    "^boxdrawing": "\x00-\xff",
+    "^boxdrawing": "\x00-\U0010ffff",
     "blockelements": "",
-    "^blockelements": "\x00-\xff",
+    "^blockelements": "\x00-\U0010ffff",
     "geometricshapes": "",
-    "^geometricshapes": "\x00-\xff",
+    "^geometricshapes": "\x00-\U0010ffff",
     "miscellaneoussymbols": "",
-    "^miscellaneoussymbols": "\x00-\xff",
+    "^miscellaneoussymbols": "\x00-\U0010ffff",
     "dingbats": "",
-    "^dingbats": "\x00-\xff",
+    "^dingbats": "\x00-\U0010ffff",
     "miscellaneousmathematicalsymbolsa": "",
-    "^miscellaneousmathematicalsymbolsa": "\x00-\xff",
+    "^miscellaneousmathematicalsymbolsa": "\x00-\U0010ffff",
     "supplementalarrowsa": "",
-    "^supplementalarrowsa": "\x00-\xff",
+    "^supplementalarrowsa": "\x00-\U0010ffff",
     "braillepatterns": "",
-    "^braillepatterns": "\x00-\xff",
+    "^braillepatterns": "\x00-\U0010ffff",
     "supplementalarrowsb": "",
-    "^supplementalarrowsb": "\x00-\xff",
+    "^supplementalarrowsb": "\x00-\U0010ffff",
     "miscellaneousmathematicalsymbolsb": "",
-    "^miscellaneousmathematicalsymbolsb": "\x00-\xff",
+    "^miscellaneousmathematicalsymbolsb": "\x00-\U0010ffff",
     "supplementalmathematicaloperators": "",
-    "^supplementalmathematicaloperators": "\x00-\xff",
+    "^supplementalmathematicaloperators": "\x00-\U0010ffff",
     "miscellaneoussymbolsandarrows": "",
-    "^miscellaneoussymbolsandarrows": "\x00-\xff",
+    "^miscellaneoussymbolsandarrows": "\x00-\U0010ffff",
     "glagolitic": "",
-    "^glagolitic": "\x00-\xff",
+    "^glagolitic": "\x00-\U0010ffff",
     "latinextendedc": "",
-    "^latinextendedc": "\x00-\xff",
+    "^latinextendedc": "\x00-\U0010ffff",
     "coptic": "",
-    "^coptic": "\x00-\xff",
+    "^coptic": "\x00-\U0010ffff",
     "georgiansupplement": "",
-    "^georgiansupplement": "\x00-\xff",
+    "^georgiansupplement": "\x00-\U0010ffff",
     "tifinagh": "",
-    "^tifinagh": "\x00-\xff",
+    "^tifinagh": "\x00-\U0010ffff",
     "ethiopicextended": "",
-    "^ethiopicextended": "\x00-\xff",
+    "^ethiopicextended": "\x00-\U0010ffff",
     "cyrillicextendeda": "",
-    "^cyrillicextendeda": "\x00-\xff",
+    "^cyrillicextendeda": "\x00-\U0010ffff",
     "supplementalpunctuation": "",
-    "^supplementalpunctuation": "\x00-\xff",
+    "^supplementalpunctuation": "\x00-\U0010ffff",
     "cjkradicalssupplement": "",
-    "^cjkradicalssupplement": "\x00-\xff",
+    "^cjkradicalssupplement": "\x00-\U0010ffff",
     "kangxiradicals": "",
-    "^kangxiradicals": "\x00-\xff",
+    "^kangxiradicals": "\x00-\U0010ffff",
     "ideographicdescriptioncharacters": "",
-    "^ideographicdescriptioncharacters": "\x00-\xff",
+    "^ideographicdescriptioncharacters": "\x00-\U0010ffff",
     "cjksymbolsandpunctuation": "",
-    "^cjksymbolsandpunctuation": "\x00-\xff",
+    "^cjksymbolsandpunctuation": "\x00-\U0010ffff",
     "hiragana": "",
-    "^hiragana": "\x00-\xff",
+    "^hiragana": "\x00-\U0010ffff",
     "katakana": "",
-    "^katakana": "\x00-\xff",
+    "^katakana": "\x00-\U0010ffff",
     "bopomofo": "",
-    "^bopomofo": "\x00-\xff",
+    "^bopomofo": "\x00-\U0010ffff",
     "hangulcompatibilityjamo": "",
-    "^hangulcompatibilityjamo": "\x00-\xff",
+    "^hangulcompatibilityjamo": "\x00-\U0010ffff",
     "kanbun": "",
-    "^kanbun": "\x00-\xff",
+    "^kanbun": "\x00-\U0010ffff",
     "bopomofoextended": "",
-    "^bopomofoextended": "\x00-\xff",
+    "^bopomofoextended": "\x00-\U0010ffff",
     "cjkstrokes": "",
-    "^cjkstrokes": "\x00-\xff",
+    "^cjkstrokes": "\x00-\U0010ffff",
     "katakanaphoneticextensions": "",
-    "^katakanaphoneticextensions": "\x00-\xff",
+    "^katakanaphoneticextensions": "\x00-\U0010ffff",
     "enclosedcjklettersandmonths": "",
-    "^enclosedcjklettersandmonths": "\x00-\xff",
+    "^enclosedcjklettersandmonths": "\x00-\U0010ffff",
     "cjkcompatibility": "",
-    "^cjkcompatibility": "\x00-\xff",
+    "^cjkcompatibility": "\x00-\U0010ffff",
     "cjkunifiedideographsextensiona": "",
-    "^cjkunifiedideographsextensiona": "\x00-\xff",
+    "^cjkunifiedideographsextensiona": "\x00-\U0010ffff",
     "yijinghexagramsymbols": "",
-    "^yijinghexagramsymbols": "\x00-\xff",
+    "^yijinghexagramsymbols": "\x00-\U0010ffff",
     "cjkunifiedideographs": "",
-    "^cjkunifiedideographs": "\x00-\xff",
+    "^cjkunifiedideographs": "\x00-\U0010ffff",
     "yisyllables": "",
-    "^yisyllables": "\x00-\xff",
+    "^yisyllables": "\x00-\U0010ffff",
     "yiradicals": "",
-    "^yiradicals": "\x00-\xff",
+    "^yiradicals": "\x00-\U0010ffff",
     "lisu": "",
-    "^lisu": "\x00-\xff",
+    "^lisu": "\x00-\U0010ffff",
     "vai": "",
-    "^vai": "\x00-\xff",
+    "^vai": "\x00-\U0010ffff",
     "cyrillicextendedb": "",
-    "^cyrillicextendedb": "\x00-\xff",
+    "^cyrillicextendedb": "\x00-\U0010ffff",
     "bamum": "",
-    "^bamum": "\x00-\xff",
+    "^bamum": "\x00-\U0010ffff",
     "modifiertoneletters": "",
-    "^modifiertoneletters": "\x00-\xff",
+    "^modifiertoneletters": "\x00-\U0010ffff",
     "latinextendedd": "",
-    "^latinextendedd": "\x00-\xff",
+    "^latinextendedd": "\x00-\U0010ffff",
     "sylotinagri": "",
-    "^sylotinagri": "\x00-\xff",
+    "^sylotinagri": "\x00-\U0010ffff",
     "commonindicnumberforms": "",
-    "^commonindicnumberforms": "\x00-\xff",
+    "^commonindicnumberforms": "\x00-\U0010ffff",
     "phagspa": "",
-    "^phagspa": "\x00-\xff",
+    "^phagspa": "\x00-\U0010ffff",
     "saurashtra": "",
-    "^saurashtra": "\x00-\xff",
+    "^saurashtra": "\x00-\U0010ffff",
     "devanagariextended": "",
-    "^devanagariextended": "\x00-\xff",
+    "^devanagariextended": "\x00-\U0010ffff",
     "kayahli": "",
-    "^kayahli": "\x00-\xff",
+    "^kayahli": "\x00-\U0010ffff",
     "rejang": "",
-    "^rejang": "\x00-\xff",
+    "^rejang": "\x00-\U0010ffff",
     "hanguljamoextendeda": "",
-    "^hanguljamoextendeda": "\x00-\xff",
+    "^hanguljamoextendeda": "\x00-\U0010ffff",
     "javanese": "",
-    "^javanese": "\x00-\xff",
+    "^javanese": "\x00-\U0010ffff",
     "myanmarextendedb": "",
-    "^myanmarextendedb": "\x00-\xff",
+    "^myanmarextendedb": "\x00-\U0010ffff",
     "cham": "",
-    "^cham": "\x00-\xff",
+    "^cham": "\x00-\U0010ffff",
     "myanmarextendeda": "",
-    "^myanmarextendeda": "\x00-\xff",
+    "^myanmarextendeda": "\x00-\U0010ffff",
     "taiviet": "",
-    "^taiviet": "\x00-\xff",
+    "^taiviet": "\x00-\U0010ffff",
     "meeteimayekextensions": "",
-    "^meeteimayekextensions": "\x00-\xff",
+    "^meeteimayekextensions": "\x00-\U0010ffff",
     "ethiopicextendeda": "",
-    "^ethiopicextendeda": "\x00-\xff",
+    "^ethiopicextendeda": "\x00-\U0010ffff",
     "latinextendede": "",
-    "^latinextendede": "\x00-\xff",
+    "^latinextendede": "\x00-\U0010ffff",
     "cherokeesupplement": "",
-    "^cherokeesupplement": "\x00-\xff",
+    "^cherokeesupplement": "\x00-\U0010ffff",
     "meeteimayek": "",
-    "^meeteimayek": "\x00-\xff",
+    "^meeteimayek": "\x00-\U0010ffff",
     "hangulsyllables": "",
-    "^hangulsyllables": "\x00-\xff",
+    "^hangulsyllables": "\x00-\U0010ffff",
     "hanguljamoextendedb": "",
-    "^hanguljamoextendedb": "\x00-\xff",
+    "^hanguljamoextendedb": "\x00-\U0010ffff",
     "highsurrogates": "",
-    "^highsurrogates": "\x00-\xff",
+    "^highsurrogates": "\x00-\U0010ffff",
     "highprivateusesurrogates": "",
-    "^highprivateusesurrogates": "\x00-\xff",
+    "^highprivateusesurrogates": "\x00-\U0010ffff",
     "lowsurrogates": "",
-    "^lowsurrogates": "\x00-\xff",
+    "^lowsurrogates": "\x00-\U0010ffff",
     "privateusearea": "",
-    "^privateusearea": "\x00-\xff",
+    "^privateusearea": "\x00-\U0010ffff",
     "cjkcompatibilityideographs": "",
-    "^cjkcompatibilityideographs": "\x00-\xff",
+    "^cjkcompatibilityideographs": "\x00-\U0010ffff",
     "alphabeticpresentationforms": "",
-    "^alphabeticpresentationforms": "\x00-\xff",
+    "^alphabeticpresentationforms": "\x00-\U0010ffff",
     "arabicpresentationformsa": "",
-    "^arabicpresentationformsa": "\x00-\xff",
+    "^arabicpresentationformsa": "\x00-\U0010ffff",
     "variationselectors": "",
-    "^variationselectors": "\x00-\xff",
+    "^variationselectors": "\x00-\U0010ffff",
     "verticalforms": "",
-    "^verticalforms": "\x00-\xff",
+    "^verticalforms": "\x00-\U0010ffff",
     "combininghalfmarks": "",
-    "^combininghalfmarks": "\x00-\xff",
+    "^combininghalfmarks": "\x00-\U0010ffff",
     "cjkcompatibilityforms": "",
-    "^cjkcompatibilityforms": "\x00-\xff",
+    "^cjkcompatibilityforms": "\x00-\U0010ffff",
     "smallformvariants": "",
-    "^smallformvariants": "\x00-\xff",
+    "^smallformvariants": "\x00-\U0010ffff",
     "arabicpresentationformsb": "",
-    "^arabicpresentationformsb": "\x00-\xff",
+    "^arabicpresentationformsb": "\x00-\U0010ffff",
     "halfwidthandfullwidthforms": "",
-    "^halfwidthandfullwidthforms": "\x00-\xff",
+    "^halfwidthandfullwidthforms": "\x00-\U0010ffff",
     "specials": "",
-    "^specials": "\x00-\xff",
+    "^specials": "\x00-\U0010ffff",
     "linearbsyllabary": "",
-    "^linearbsyllabary": "\x00-\xff",
+    "^linearbsyllabary": "\x00-\U0010ffff",
     "linearbideograms": "",
-    "^linearbideograms": "\x00-\xff",
+    "^linearbideograms": "\x00-\U0010ffff",
     "aegeannumbers": "",
-    "^aegeannumbers": "\x00-\xff",
+    "^aegeannumbers": "\x00-\U0010ffff",
     "ancientgreeknumbers": "",
-    "^ancientgreeknumbers": "\x00-\xff",
+    "^ancientgreeknumbers": "\x00-\U0010ffff",
     "ancientsymbols": "",
-    "^ancientsymbols": "\x00-\xff",
+    "^ancientsymbols": "\x00-\U0010ffff",
     "phaistosdisc": "",
-    "^phaistosdisc": "\x00-\xff",
+    "^phaistosdisc": "\x00-\U0010ffff",
     "lycian": "",
-    "^lycian": "\x00-\xff",
+    "^lycian": "\x00-\U0010ffff",
     "carian": "",
-    "^carian": "\x00-\xff",
+    "^carian": "\x00-\U0010ffff",
     "copticepactnumbers": "",
-    "^copticepactnumbers": "\x00-\xff",
+    "^copticepactnumbers": "\x00-\U0010ffff",
     "olditalic": "",
-    "^olditalic": "\x00-\xff",
+    "^olditalic": "\x00-\U0010ffff",
     "gothic": "",
-    "^gothic": "\x00-\xff",
+    "^gothic": "\x00-\U0010ffff",
     "oldpermic": "",
-    "^oldpermic": "\x00-\xff",
+    "^oldpermic": "\x00-\U0010ffff",
     "ugaritic": "",
-    "^ugaritic": "\x00-\xff",
+    "^ugaritic": "\x00-\U0010ffff",
     "oldpersian": "",
-    "^oldpersian": "\x00-\xff",
+    "^oldpersian": "\x00-\U0010ffff",
     "deseret": "",
-    "^deseret": "\x00-\xff",
+    "^deseret": "\x00-\U0010ffff",
     "shavian": "",
-    "^shavian": "\x00-\xff",
+    "^shavian": "\x00-\U0010ffff",
     "osmanya": "",
-    "^osmanya": "\x00-\xff",
+    "^osmanya": "\x00-\U0010ffff",
     "osage": "",
-    "^osage": "\x00-\xff",
+    "^osage": "\x00-\U0010ffff",
     "elbasan": "",
-    "^elbasan": "\x00-\xff",
+    "^elbasan": "\x00-\U0010ffff",
     "caucasianalbanian": "",
-    "^caucasianalbanian": "\x00-\xff",
+    "^caucasianalbanian": "\x00-\U0010ffff",
     "lineara": "",
-    "^lineara": "\x00-\xff",
+    "^lineara": "\x00-\U0010ffff",
     "cypriotsyllabary": "",
-    "^cypriotsyllabary": "\x00-\xff",
+    "^cypriotsyllabary": "\x00-\U0010ffff",
     "imperialaramaic": "",
-    "^imperialaramaic": "\x00-\xff",
+    "^imperialaramaic": "\x00-\U0010ffff",
     "palmyrene": "",
-    "^palmyrene": "\x00-\xff",
+    "^palmyrene": "\x00-\U0010ffff",
     "nabataean": "",
-    "^nabataean": "\x00-\xff",
+    "^nabataean": "\x00-\U0010ffff",
     "hatran": "",
-    "^hatran": "\x00-\xff",
+    "^hatran": "\x00-\U0010ffff",
     "phoenician": "",
-    "^phoenician": "\x00-\xff",
+    "^phoenician": "\x00-\U0010ffff",
     "lydian": "",
-    "^lydian": "\x00-\xff",
+    "^lydian": "\x00-\U0010ffff",
     "meroitichieroglyphs": "",
-    "^meroitichieroglyphs": "\x00-\xff",
+    "^meroitichieroglyphs": "\x00-\U0010ffff",
     "meroiticcursive": "",
-    "^meroiticcursive": "\x00-\xff",
+    "^meroiticcursive": "\x00-\U0010ffff",
     "kharoshthi": "",
-    "^kharoshthi": "\x00-\xff",
+    "^kharoshthi": "\x00-\U0010ffff",
     "oldsoutharabian": "",
-    "^oldsoutharabian": "\x00-\xff",
+    "^oldsoutharabian": "\x00-\U0010ffff",
     "oldnortharabian": "",
-    "^oldnortharabian": "\x00-\xff",
+    "^oldnortharabian": "\x00-\U0010ffff",
     "manichaean": "",
-    "^manichaean": "\x00-\xff",
+    "^manichaean": "\x00-\U0010ffff",
     "avestan": "",
-    "^avestan": "\x00-\xff",
+    "^avestan": "\x00-\U0010ffff",
     "inscriptionalparthian": "",
-    "^inscriptionalparthian": "\x00-\xff",
+    "^inscriptionalparthian": "\x00-\U0010ffff",
     "inscriptionalpahlavi": "",
-    "^inscriptionalpahlavi": "\x00-\xff",
+    "^inscriptionalpahlavi": "\x00-\U0010ffff",
     "psalterpahlavi": "",
-    "^psalterpahlavi": "\x00-\xff",
+    "^psalterpahlavi": "\x00-\U0010ffff",
     "oldturkic": "",
-    "^oldturkic": "\x00-\xff",
+    "^oldturkic": "\x00-\U0010ffff",
     "oldhungarian": "",
-    "^oldhungarian": "\x00-\xff",
+    "^oldhungarian": "\x00-\U0010ffff",
     "ruminumeralsymbols": "",
-    "^ruminumeralsymbols": "\x00-\xff",
+    "^ruminumeralsymbols": "\x00-\U0010ffff",
     "brahmi": "",
-    "^brahmi": "\x00-\xff",
+    "^brahmi": "\x00-\U0010ffff",
     "kaithi": "",
-    "^kaithi": "\x00-\xff",
+    "^kaithi": "\x00-\U0010ffff",
     "sorasompeng": "",
-    "^sorasompeng": "\x00-\xff",
+    "^sorasompeng": "\x00-\U0010ffff",
     "chakma": "",
-    "^chakma": "\x00-\xff",
+    "^chakma": "\x00-\U0010ffff",
     "mahajani": "",
-    "^mahajani": "\x00-\xff",
+    "^mahajani": "\x00-\U0010ffff",
     "sharada": "",
-    "^sharada": "\x00-\xff",
+    "^sharada": "\x00-\U0010ffff",
     "sinhalaarchaicnumbers": "",
-    "^sinhalaarchaicnumbers": "\x00-\xff",
+    "^sinhalaarchaicnumbers": "\x00-\U0010ffff",
     "khojki": "",
-    "^khojki": "\x00-\xff",
+    "^khojki": "\x00-\U0010ffff",
     "multani": "",
-    "^multani": "\x00-\xff",
+    "^multani": "\x00-\U0010ffff",
     "khudawadi": "",
-    "^khudawadi": "\x00-\xff",
+    "^khudawadi": "\x00-\U0010ffff",
     "grantha": "",
-    "^grantha": "\x00-\xff",
+    "^grantha": "\x00-\U0010ffff",
     "newa": "",
-    "^newa": "\x00-\xff",
+    "^newa": "\x00-\U0010ffff",
     "tirhuta": "",
-    "^tirhuta": "\x00-\xff",
+    "^tirhuta": "\x00-\U0010ffff",
     "siddham": "",
-    "^siddham": "\x00-\xff",
+    "^siddham": "\x00-\U0010ffff",
     "modi": "",
-    "^modi": "\x00-\xff",
+    "^modi": "\x00-\U0010ffff",
     "mongoliansupplement": "",
-    "^mongoliansupplement": "\x00-\xff",
+    "^mongoliansupplement": "\x00-\U0010ffff",
     "takri": "",
-    "^takri": "\x00-\xff",
+    "^takri": "\x00-\U0010ffff",
     "ahom": "",
-    "^ahom": "\x00-\xff",
+    "^ahom": "\x00-\U0010ffff",
     "warangciti": "",
-    "^warangciti": "\x00-\xff",
+    "^warangciti": "\x00-\U0010ffff",
     "paucinhau": "",
-    "^paucinhau": "\x00-\xff",
+    "^paucinhau": "\x00-\U0010ffff",
     "bhaiksuki": "",
-    "^bhaiksuki": "\x00-\xff",
+    "^bhaiksuki": "\x00-\U0010ffff",
     "marchen": "",
-    "^marchen": "\x00-\xff",
+    "^marchen": "\x00-\U0010ffff",
     "cuneiform": "",
-    "^cuneiform": "\x00-\xff",
+    "^cuneiform": "\x00-\U0010ffff",
     "cuneiformnumbersandpunctuation": "",
-    "^cuneiformnumbersandpunctuation": "\x00-\xff",
+    "^cuneiformnumbersandpunctuation": "\x00-\U0010ffff",
     "earlydynasticcuneiform": "",
-    "^earlydynasticcuneiform": "\x00-\xff",
+    "^earlydynasticcuneiform": "\x00-\U0010ffff",
     "egyptianhieroglyphs": "",
-    "^egyptianhieroglyphs": "\x00-\xff",
+    "^egyptianhieroglyphs": "\x00-\U0010ffff",
     "anatolianhieroglyphs": "",
-    "^anatolianhieroglyphs": "\x00-\xff",
+    "^anatolianhieroglyphs": "\x00-\U0010ffff",
     "bamumsupplement": "",
-    "^bamumsupplement": "\x00-\xff",
+    "^bamumsupplement": "\x00-\U0010ffff",
     "mro": "",
-    "^mro": "\x00-\xff",
+    "^mro": "\x00-\U0010ffff",
     "bassavah": "",
-    "^bassavah": "\x00-\xff",
+    "^bassavah": "\x00-\U0010ffff",
     "pahawhhmong": "",
-    "^pahawhhmong": "\x00-\xff",
+    "^pahawhhmong": "\x00-\U0010ffff",
     "miao": "",
-    "^miao": "\x00-\xff",
+    "^miao": "\x00-\U0010ffff",
     "ideographicsymbolsandpunctuation": "",
-    "^ideographicsymbolsandpunctuation": "\x00-\xff",
+    "^ideographicsymbolsandpunctuation": "\x00-\U0010ffff",
     "tangut": "",
-    "^tangut": "\x00-\xff",
+    "^tangut": "\x00-\U0010ffff",
     "tangutcomponents": "",
-    "^tangutcomponents": "\x00-\xff",
+    "^tangutcomponents": "\x00-\U0010ffff",
     "kanasupplement": "",
-    "^kanasupplement": "\x00-\xff",
+    "^kanasupplement": "\x00-\U0010ffff",
     "duployan": "",
-    "^duployan": "\x00-\xff",
+    "^duployan": "\x00-\U0010ffff",
     "shorthandformatcontrols": "",
-    "^shorthandformatcontrols": "\x00-\xff",
+    "^shorthandformatcontrols": "\x00-\U0010ffff",
     "byzantinemusicalsymbols": "",
-    "^byzantinemusicalsymbols": "\x00-\xff",
+    "^byzantinemusicalsymbols": "\x00-\U0010ffff",
     "musicalsymbols": "",
-    "^musicalsymbols": "\x00-\xff",
+    "^musicalsymbols": "\x00-\U0010ffff",
     "ancientgreekmusicalnotation": "",
-    "^ancientgreekmusicalnotation": "\x00-\xff",
+    "^ancientgreekmusicalnotation": "\x00-\U0010ffff",
     "taixuanjingsymbols": "",
-    "^taixuanjingsymbols": "\x00-\xff",
+    "^taixuanjingsymbols": "\x00-\U0010ffff",
     "countingrodnumerals": "",
-    "^countingrodnumerals": "\x00-\xff",
+    "^countingrodnumerals": "\x00-\U0010ffff",
     "mathematicalalphanumericsymbols": "",
-    "^mathematicalalphanumericsymbols": "\x00-\xff",
+    "^mathematicalalphanumericsymbols": "\x00-\U0010ffff",
     "suttonsignwriting": "",
-    "^suttonsignwriting": "\x00-\xff",
+    "^suttonsignwriting": "\x00-\U0010ffff",
     "glagoliticsupplement": "",
-    "^glagoliticsupplement": "\x00-\xff",
+    "^glagoliticsupplement": "\x00-\U0010ffff",
     "mendekikakui": "",
-    "^mendekikakui": "\x00-\xff",
+    "^mendekikakui": "\x00-\U0010ffff",
     "adlam": "",
-    "^adlam": "\x00-\xff",
+    "^adlam": "\x00-\U0010ffff",
     "arabicmathematicalalphabeticsymbols": "",
-    "^arabicmathematicalalphabeticsymbols": "\x00-\xff",
+    "^arabicmathematicalalphabeticsymbols": "\x00-\U0010ffff",
     "mahjongtiles": "",
-    "^mahjongtiles": "\x00-\xff",
+    "^mahjongtiles": "\x00-\U0010ffff",
     "dominotiles": "",
-    "^dominotiles": "\x00-\xff",
+    "^dominotiles": "\x00-\U0010ffff",
     "playingcards": "",
-    "^playingcards": "\x00-\xff",
+    "^playingcards": "\x00-\U0010ffff",
     "enclosedalphanumericsupplement": "",
-    "^enclosedalphanumericsupplement": "\x00-\xff",
+    "^enclosedalphanumericsupplement": "\x00-\U0010ffff",
     "enclosedideographicsupplement": "",
-    "^enclosedideographicsupplement": "\x00-\xff",
+    "^enclosedideographicsupplement": "\x00-\U0010ffff",
     "miscellaneoussymbolsandpictographs": "",
-    "^miscellaneoussymbolsandpictographs": "\x00-\xff",
+    "^miscellaneoussymbolsandpictographs": "\x00-\U0010ffff",
     "emoticons": "",
-    "^emoticons": "\x00-\xff",
+    "^emoticons": "\x00-\U0010ffff",
     "ornamentaldingbats": "",
-    "^ornamentaldingbats": "\x00-\xff",
+    "^ornamentaldingbats": "\x00-\U0010ffff",
     "transportandmapsymbols": "",
-    "^transportandmapsymbols": "\x00-\xff",
+    "^transportandmapsymbols": "\x00-\U0010ffff",
     "alchemicalsymbols": "",
-    "^alchemicalsymbols": "\x00-\xff",
+    "^alchemicalsymbols": "\x00-\U0010ffff",
     "geometricshapesextended": "",
-    "^geometricshapesextended": "\x00-\xff",
+    "^geometricshapesextended": "\x00-\U0010ffff",
     "supplementalarrowsc": "",
-    "^supplementalarrowsc": "\x00-\xff",
+    "^supplementalarrowsc": "\x00-\U0010ffff",
     "supplementalsymbolsandpictographs": "",
-    "^supplementalsymbolsandpictographs": "\x00-\xff",
+    "^supplementalsymbolsandpictographs": "\x00-\U0010ffff",
     "cjkunifiedideographsextensionb": "",
-    "^cjkunifiedideographsextensionb": "\x00-\xff",
+    "^cjkunifiedideographsextensionb": "\x00-\U0010ffff",
     "cjkunifiedideographsextensionc": "",
-    "^cjkunifiedideographsextensionc": "\x00-\xff",
+    "^cjkunifiedideographsextensionc": "\x00-\U0010ffff",
     "cjkunifiedideographsextensiond": "",
-    "^cjkunifiedideographsextensiond": "\x00-\xff",
+    "^cjkunifiedideographsextensiond": "\x00-\U0010ffff",
     "cjkunifiedideographsextensione": "",
-    "^cjkunifiedideographsextensione": "\x00-\xff",
+    "^cjkunifiedideographsextensione": "\x00-\U0010ffff",
     "cjkcompatibilityideographssupplement": "",
-    "^cjkcompatibilityideographssupplement": "\x00-\xff",
+    "^cjkcompatibilityideographssupplement": "\x00-\U0010ffff",
     "tags": "",
-    "^tags": "\x00-\xff",
+    "^tags": "\x00-\U0010ffff",
     "variationselectorssupplement": "",
-    "^variationselectorssupplement": "\x00-\xff",
+    "^variationselectorssupplement": "\x00-\U0010ffff",
     "supplementaryprivateuseareaa": "",
-    "^supplementaryprivateuseareaa": "\x00-\xff",
+    "^supplementaryprivateuseareaa": "\x00-\U0010ffff",
     "supplementaryprivateuseareab": "",
-    "^supplementaryprivateuseareab": "\x00-\xff",
+    "^supplementaryprivateuseareab": "\x00-\U0010ffff",
     "noblock": "",
-    "^noblock": "\x00-\xff",
+    "^noblock": "\x00-\U0010ffff",
 }
